@@ -5,12 +5,18 @@ import rasterio
 from rasterio.features import rasterize
 from rasterio.transform import IDENTITY
 
+
 logging.basicConfig(stream=sys.stderr, level=logging.INFO)
 logger = logging.getLogger('rasterize_geometry')
 
 
 rows = cols = 10
-geometry = {'type':'Polygon','coordinates':[[(2,2),(2,4.25),(4.25,4.25),(4.25,2),(2,2)]]}
+
+geometry = {
+    'type': 'Polygon',
+    'coordinates': [[(2, 2), (2, 4.25), (4.25, 4.25), (4.25, 2), (2, 2)]]}
+
+
 with rasterio.drivers():
     result = rasterize([geometry], out_shape=(rows, cols))
     with rasterio.open(
@@ -24,4 +30,4 @@ with rasterio.drivers():
             nodata=0,
             transform=IDENTITY,
             crs={'init': "EPSG:4326"}) as out:
-        out.write_band(1, result.astype(numpy.uint8))
+        out.write(result.astype(numpy.uint8), indexes=1)
