@@ -10,6 +10,7 @@ from cligj import (
 
 from .helpers import write_features, to_lower
 import rasterio
+from rasterio.env import Env
 from rasterio.warp import transform_bounds
 
 logger = logging.getLogger('rio')
@@ -47,7 +48,6 @@ def bounds(ctx, input, precision, indent, compact, projection, dst_crs,
     """
     import rasterio.warp
     verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
-    aws_session = (ctx.obj and ctx.obj.get('aws_session'))
     logger = logging.getLogger('rio')
     dump_kwds = {'sort_keys': True}
     if indent:
@@ -59,9 +59,10 @@ def bounds(ctx, input, precision, indent, compact, projection, dst_crs,
     # This is the generator for (feature, bbox) pairs.
     class Collection(object):
 
-        def __init__(self):
+        def __init__(self, env):
             self._xs = []
             self._ys = []
+            self.env = env
 
         @property
         def bbox(self):
@@ -105,13 +106,10 @@ def bounds(ctx, input, precision, indent, compact, projection, dst_crs,
                 self._xs.extend(bbox[::2])
                 self._ys.extend(bbox[1::2])
 
-    col = Collection()
-    # Use the generator defined above as input to the generic output
-    # writing function.
     try:
-        with rasterio.drivers(CPL_DEBUG=verbosity > 2), aws_session:
+        with Env(CPL_DEBUG=verbosity > 2) as env:
             write_features(
-                stdout, col, sequence=sequence,
+                stdout, Collection(env), sequence=sequence,
                 geojson_type=geojson_type, use_rs=use_rs,
                 **dump_kwds)
 
