@@ -1,13 +1,12 @@
 """Fetch and edit raster dataset metadata from the command line."""
 
 import json
-import logging
 
 import click
 
 from . import options
-import rasterio
 import rasterio.crs
+from rasterio.env import Env
 
 
 @click.command(short_help="Print information about a data file.")
@@ -62,13 +61,9 @@ def info(ctx, input, aspect, indent, namespace, meta_member, verbose, bidx,
     Optionally print a single metadata item as a string.
     """
     verbosity = ctx.obj.get('verbosity')
-    aws_session = ctx.obj.get('aws_session')
-
-    logger = logging.getLogger('rio')
     mode = 'r' if (verbose or meta_member == 'stats') else 'r-'
     try:
-        with rasterio.drivers(
-                CPL_DEBUG=(verbosity > 2)), aws_session:
+        with Env(CPL_DEBUG=(verbosity > 2)):
             with rasterio.open(input, mode) as src:
                 info = src.profile
                 info['transform'] = info['affine'][:6]
@@ -109,5 +104,4 @@ def info(ctx, input, aspect, indent, namespace, meta_member, verbose, bidx,
                     click.echo(
                         json.dumps(src.tags(ns=namespace), indent=indent))
     except Exception:
-        logger.exception("Exception caught during processing")
         raise click.Abort()
