@@ -12,14 +12,15 @@ import numpy
 import click
 
 from . import options
-from rasterio.plot import show, show_hist
 import rasterio
+from rasterio.env import Env
+from rasterio.plot import show, show_hist
 
 try:
     import matplotlib.pyplot as plt
-except ImportError:
+except ImportError:  # pragma: no cover
     plt = None
-except RuntimeError as e:
+except RuntimeError as e:  # pragma: no cover
     # Certain environment configurations can trigger a RuntimeError like:
 
     # Trying to import matplotlibRuntimeError: Python is not installed as a
@@ -52,7 +53,7 @@ def main(banner, dataset, alt_interpreter=None):
     local = dict(funcs, src=dataset, np=numpy, rio=rasterio, plt=plt)
     if not alt_interpreter:
         code.interact(banner, local=local)
-    elif alt_interpreter == 'ipython':
+    elif alt_interpreter == 'ipython':  # pragma: no cover
         import IPython
         IPython.InteractiveShell.banner1 = banner
         IPython.start_ipython(argv=[], user_ns=local)
@@ -77,10 +78,9 @@ def insp(ctx, input, mode, interpreter):
     """ Open the input file in a Python interpreter.
     """
     verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
-    aws_session = (ctx.obj and ctx.obj.get('aws_session'))
     logger = logging.getLogger('rio')
     try:
-        with rasterio.drivers(CPL_DEBUG=verbosity > 2), aws_session:
+        with Env(CPL_DEBUG=verbosity > 2) as env:
             with rasterio.open(input, mode) as src:
                 main(
                     'Rasterio %s Interactive Inspector (Python %s)\n'
