@@ -11,6 +11,8 @@ from . import options
 import rasterio
 from rasterio.transform import Affine
 from rasterio.coords import disjoint_bounds
+from rasterio.env import Env
+
 
 logger = logging.getLogger('rio')
 
@@ -126,7 +128,7 @@ def rasterize(
     if fill == int(fill):
         fill = int(fill)
 
-    with rasterio.drivers(CPL_DEBUG=verbosity > 2):
+    with Env(CPL_DEBUG=verbosity > 2):
 
         def feature_value(feature):
             if prop and 'properties' in feature:
@@ -177,7 +179,7 @@ def rasterize(
                     ne = result != fill
                     data[ne] = result[ne]
                     data.mask[ne] = False
-                    out.write_band(bidx, data)
+                    out.write(data, indexes=bidx)
 
         else:
             if like is not None:
@@ -268,4 +270,4 @@ def rasterize(
             kwargs['nodata'] = fill
 
             with rasterio.open(output, 'w', **kwargs) as out:
-                out.write_band(1, result)
+                out.write(result, indexes=1)
