@@ -8,6 +8,7 @@ import rasterio
 from rasterio import crs
 from rasterio.crs import (
     is_geographic_crs, is_projected_crs, is_same_crs, is_valid_crs)
+from rasterio.errors import CRSError
 
 
 logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
@@ -15,30 +16,27 @@ logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
 
 # When possible, Rasterio gives you the CRS in the form of an EPSG code.
 def test_read_epsg(tmpdir):
-    with rasterio.drivers():
-        with rasterio.open('tests/data/RGB.byte.tif') as src:
-            assert src.crs == {'init': 'epsg:32618'}
+    with rasterio.open('tests/data/RGB.byte.tif') as src:
+        assert src.crs == {'init': 'epsg:32618'}
 
 def test_read_epsg3857(tmpdir):
     tiffname = str(tmpdir.join('lol.tif'))
     subprocess.call([
-        'gdalwarp', '-t_srs', 'EPSG:3857', 
+        'gdalwarp', '-t_srs', 'EPSG:3857',
         'tests/data/RGB.byte.tif', tiffname])
-    with rasterio.drivers():
-        with rasterio.open(tiffname) as src:
-            assert src.crs == {'init': 'epsg:3857'}
+    with rasterio.open(tiffname) as src:
+        assert src.crs == {'init': 'epsg:3857'}
 
 # Ensure that CRS sticks when we write a file.
 def test_write_3857(tmpdir):
     src_path = str(tmpdir.join('lol.tif'))
     subprocess.call([
-        'gdalwarp', '-t_srs', 'EPSG:3857', 
+        'gdalwarp', '-t_srs', 'EPSG:3857',
         'tests/data/RGB.byte.tif', src_path])
     dst_path = str(tmpdir.join('wut.tif'))
-    with rasterio.drivers():
-        with rasterio.open(src_path) as src:
-            with rasterio.open(dst_path, 'w', **src.meta) as dst:
-                assert dst.crs == {'init': 'epsg:3857'}
+    with rasterio.open(src_path) as src:
+        with rasterio.open(dst_path, 'w', **src.meta) as dst:
+            assert dst.crs == {'init': 'epsg:3857'}
     info = subprocess.check_output([
         'gdalinfo', dst_path])
     # WKT string may vary a bit w.r.t GDAL versions
@@ -146,3 +144,12 @@ def test_is_valid_false():
 
 def test_is_valid():
     assert is_valid_crs('EPSG:4326')
+
+
+def test_empty_json():
+    with pytest.raises(CRSError):
+        crs.from_string('{}')
+    with pytest.raises(CRSError):
+        crs.from_string('[]')
+    with pytest.raises(CRSError):
+        crs.from_string('')
