@@ -22,9 +22,9 @@ class ReaderContextTest(unittest.TestCase):
             self.assertEqual(s.width, 791)
             self.assertEqual(s.height, 718)
             self.assertEqual(s.shape, (718, 791))
-            self.assertEqual(s.dtypes, [rasterio.ubyte]*3)
-            self.assertEqual(s.nodatavals, [0]*3)
-            self.assertEqual(s.indexes, [1,2,3])
+            self.assertEqual(s.dtypes, tuple([rasterio.ubyte] * 3))
+            self.assertEqual(s.nodatavals, (0, 0, 0))
+            self.assertEqual(s.indexes, (1, 2, 3))
             self.assertEqual(s.crs['init'], 'epsg:32618')
             self.assert_(s.crs_wkt.startswith('PROJCS'), s.crs_wkt)
             for i, v in enumerate((101985.0, 2611485.0, 339315.0, 2826915.0)):
@@ -44,8 +44,8 @@ class ReaderContextTest(unittest.TestCase):
         self.assertEqual(s.width, 791)
         self.assertEqual(s.height, 718)
         self.assertEqual(s.shape, (718, 791))
-        self.assertEqual(s.dtypes, [rasterio.ubyte]*3)
-        self.assertEqual(s.nodatavals, [0]*3)
+        self.assertEqual(s.dtypes, tuple([rasterio.ubyte] * 3))
+        self.assertEqual(s.nodatavals, (0, 0, 0))
         self.assertEqual(s.crs['init'], 'epsg:32618')
         self.assertEqual(
             s.affine, 
@@ -67,24 +67,24 @@ class ReaderContextTest(unittest.TestCase):
 
     def test_read_ubyte(self):
         with rasterio.open('tests/data/RGB.byte.tif') as s:
-            a = s.read_band(1)
+            a = s.read(1)
             self.assertEqual(a.dtype, rasterio.ubyte)
 
     def test_read_ubyte_bad_index(self):
         with rasterio.open('tests/data/RGB.byte.tif') as s:
-            self.assertRaises(IndexError, s.read_band, 0)
+            self.assertRaises(IndexError, s.read, 0)
 
     def test_read_ubyte_out(self):
         with rasterio.open('tests/data/RGB.byte.tif') as s:
             a = numpy.zeros((718, 791), dtype=rasterio.ubyte)
-            a = s.read_band(1, a)
+            a = s.read(1, a)
             self.assertEqual(a.dtype, rasterio.ubyte)
 
     def test_read_out_dtype_fail(self):
         with rasterio.open('tests/data/RGB.byte.tif') as s:
             a = numpy.zeros((718, 791), dtype=rasterio.float32)
             try:
-                s.read_band(1, a)
+                s.read(1, a)
             except ValueError as e:
                 assert "the array's dtype 'float32' does not match the file's dtype" in str(e)
             except:
