@@ -180,9 +180,8 @@ def test_mask_crop(runner, tmpdir, basic_feature, pixelated_image):
         "width": image.shape[1],
         "height": image.shape[0],
         "nodata": 255}
-    with rasterio.drivers():
-        with rasterio.open(outfilename, 'w', **kwargs) as out:
-            out.write_band(1, image)
+    with rasterio.open(outfilename, 'w', **kwargs) as out:
+        out.write(image, indexes=1)
 
     output = str(tmpdir.join('test.tif'))
 
@@ -317,7 +316,7 @@ def test_shapes_with_nodata(runner, pixelated_image, pixelated_image_file):
     pixelated_image[0:2, 8:10] = 255
 
     with rasterio.open(pixelated_image_file, 'r+') as out:
-        out.write_band(1, pixelated_image)
+        out.write(pixelated_image, indexes=1)
 
     result = runner.invoke(
         main_group, ['shapes', pixelated_image_file, '--with-nodata'])
@@ -382,7 +381,7 @@ def test_shapes_mask(runner, pixelated_image, pixelated_image_file):
     pixelated_image[8:10, 8:10] = 255
 
     with rasterio.open(pixelated_image_file, 'r+') as out:
-        out.write_band(1, pixelated_image)
+        out.write(pixelated_image, indexes=1)
 
     result = runner.invoke(
         main_group, ['shapes', pixelated_image_file, '--mask'])
@@ -409,7 +408,7 @@ def test_shapes_mask_sampling(runner, pixelated_image, pixelated_image_file):
     pixelated_image[8:10, 8:10] = 255
 
     with rasterio.open(pixelated_image_file, 'r+') as out:
-        out.write_band(1, pixelated_image)
+        out.write(pixelated_image, indexes=1)
 
     result = runner.invoke(
         main_group,
@@ -433,7 +432,7 @@ def test_shapes_band1_as_mask(runner, pixelated_image, pixelated_image_file):
     pixelated_image[2:3, 2:3] = 4
 
     with rasterio.open(pixelated_image_file, 'r+') as out:
-        out.write_band(1, pixelated_image)
+        out.write(pixelated_image, indexes=1)
 
     result = runner.invoke(
         main_group,
@@ -497,6 +496,23 @@ def test_rasterize_resolution(tmpdir, runner, basic_feature):
         assert numpy.all(data)
 
 
+def test_rasterize_multiresolution(tmpdir, runner, basic_feature):
+    output = str(tmpdir.join('test.tif'))
+    result = runner.invoke(
+        rasterize,
+        [output, '--res', 0.15, '--res', 0.15],
+        input=json.dumps(basic_feature)
+    )
+
+    assert result.exit_code == 0
+    assert os.path.exists(output)
+    with rasterio.open(output) as out:
+        assert numpy.allclose(out.bounds, (2, 2, 4.25, 4.25))
+        data = out.read(1, masked=False)
+        assert data.shape == (15, 15)
+        assert numpy.all(data)
+
+
 def test_rasterize_src_crs(tmpdir, runner, basic_feature):
     output = str(tmpdir.join('test.tif'))
     result = runner.invoke(
@@ -623,6 +639,39 @@ def test_rasterize_like_raster_src_crs_mismatch(tmpdir, runner, basic_feature,
     assert 'GeoJSON does not match crs of --like raster' in result.output
 
 
+def test_rasterize_featurecollection(tmpdir, runner, basic_feature,
+                                     pixelated_image_file):
+    output = str(tmpdir.join('test.tif'))
+    collection = {
+        'type': 'FeatureCollection',
+        'features': [basic_feature]}
+    result = runner.invoke(
+        rasterize,
+        [output, '--like', pixelated_image_file],
+        input=json.dumps(collection)
+    )
+    assert result.exit_code == 0
+
+
+def test_rasterize_src_crs_mismatch(tmpdir, runner, basic_feature,
+                                    pixelated_image_file):
+    output = str(tmpdir.join('test.tif'))
+    result = runner.invoke(
+        rasterize,
+        [output, '--like', pixelated_image_file],
+        input=json.dumps(basic_feature)
+    )
+    assert result.exit_code == 0
+
+    result = runner.invoke(
+        rasterize,
+        [output, '--force-overwrite', '--src-crs', 'EPSG:3857'],
+        input=json.dumps(basic_feature)
+    )
+    assert result.exit_code == 2
+    assert 'GeoJSON does not match crs of existing output raster' in result.output
+
+
 def test_rasterize_property_value(tmpdir, runner, basic_feature):
     output = str(tmpdir.join('test.tif'))
     result = runner.invoke(
@@ -661,7 +710,7 @@ def test_rasterize_like_raster_outside_bounds(tmpdir, runner, basic_feature,
     assert 'outside bounds' in result.output
     assert os.path.exists(output)
     with rasterio.open(output) as out:
-        assert not numpy.any(out.read_band(1, masked=False))
+        assert not numpy.any(out.read(1, masked=False))
 
 
 def test_rasterize_invalid_stdin(tmpdir, runner):
