@@ -28,17 +28,15 @@ def test_data_dir_1(tmpdir):
         "nodata": 1
     }
 
-    with rasterio.drivers():
+    with rasterio.open(str(tmpdir.join('b.tif')), 'w', **kwargs) as dst:
+        data = numpy.ones((10, 10), dtype=rasterio.uint8)
+        data[0:6, 0:6] = 255
+        dst.write(data, indexes=1)
 
-        with rasterio.open(str(tmpdir.join('b.tif')), 'w', **kwargs) as dst:
-            data = numpy.ones((10, 10), dtype=rasterio.uint8)
-            data[0:6, 0:6] = 255
-            dst.write_band(1, data)
-
-        with rasterio.open(str(tmpdir.join('a.tif')), 'w', **kwargs) as dst:
-            data = numpy.ones((10, 10), dtype=rasterio.uint8)
-            data[4:8, 4:8] = 254
-            dst.write_band(1, data)
+    with rasterio.open(str(tmpdir.join('a.tif')), 'w', **kwargs) as dst:
+        data = numpy.ones((10, 10), dtype=rasterio.uint8)
+        data[4:8, 4:8] = 254
+        dst.write(data, indexes=1)
 
     return tmpdir
 
@@ -56,17 +54,15 @@ def test_data_dir_2(tmpdir):
         # these files have undefined nodata.
     }
 
-    with rasterio.drivers():
+    with rasterio.open(str(tmpdir.join('b.tif')), 'w', **kwargs) as dst:
+        data = numpy.zeros((10, 10), dtype=rasterio.uint8)
+        data[0:6, 0:6] = 255
+        dst.write(data, indexes=1)
 
-        with rasterio.open(str(tmpdir.join('b.tif')), 'w', **kwargs) as dst:
-            data = numpy.zeros((10, 10), dtype=rasterio.uint8)
-            data[0:6, 0:6] = 255
-            dst.write_band(1, data)
-
-        with rasterio.open(str(tmpdir.join('a.tif')), 'w', **kwargs) as dst:
-            data = numpy.zeros((10, 10), dtype=rasterio.uint8)
-            data[4:8, 4:8] = 254
-            dst.write_band(1, data)
+    with rasterio.open(str(tmpdir.join('a.tif')), 'w', **kwargs) as dst:
+        data = numpy.zeros((10, 10), dtype=rasterio.uint8)
+        data[4:8, 4:8] = 254
+        dst.write(data, indexes=1)
 
     return tmpdir
 
@@ -81,7 +77,7 @@ def test_merge_with_nodata(test_data_dir_1):
     assert os.path.exists(outputname)
     with rasterio.open(outputname) as out:
         assert out.count == 1
-        data = out.read_band(1, masked=False)
+        data = out.read(1, masked=False)
         expected = numpy.ones((10, 10), dtype=rasterio.uint8)
         expected[0:6, 0:6] = 255
         expected[4:8, 4:8] = 254
@@ -109,7 +105,7 @@ def test_merge_without_nodata(test_data_dir_2):
     assert os.path.exists(outputname)
     with rasterio.open(outputname) as out:
         assert out.count == 1
-        data = out.read_band(1, masked=False)
+        data = out.read(1, masked=False)
         expected = numpy.zeros((10, 10), dtype=rasterio.uint8)
         expected[0:6, 0:6] = 255
         expected[4:8, 4:8] = 254
@@ -184,15 +180,14 @@ def test_data_dir_overlapping(tmpdir):
         "nodata": 0
     }
 
-    with rasterio.drivers():
-        with rasterio.open(str(tmpdir.join('se.tif')), 'w', **kwargs) as dst:
-            data = numpy.ones((10, 10), dtype=rasterio.uint8)
-            dst.write_band(1, data)
+    with rasterio.open(str(tmpdir.join('se.tif')), 'w', **kwargs) as dst:
+        data = numpy.ones((10, 10), dtype=rasterio.uint8)
+        dst.write(data, indexes=1)
 
-        kwargs['transform'] = (-113, 0.2, 0, 45, 0, -0.2)
-        with rasterio.open(str(tmpdir.join('nw.tif')), 'w', **kwargs) as dst:
-            data = numpy.ones((10, 10), dtype=rasterio.uint8) * 2
-            dst.write_band(1, data)
+    kwargs['transform'] = (-113, 0.2, 0, 45, 0, -0.2)
+    with rasterio.open(str(tmpdir.join('nw.tif')), 'w', **kwargs) as dst:
+        data = numpy.ones((10, 10), dtype=rasterio.uint8) * 2
+        dst.write(data, indexes=1)
 
     return tmpdir
 
@@ -209,7 +204,7 @@ def test_merge_overlapping(test_data_dir_overlapping):
         assert out.count == 1
         assert out.shape == (15, 15)
         assert out.bounds == (-114, 43, -111, 46)
-        data = out.read_band(1, masked=False)
+        data = out.read(1, masked=False)
         expected = numpy.zeros((15, 15), dtype=rasterio.uint8)
         expected[0:10, 0:10] = 1
         expected[5:, 5:] = 2
@@ -230,16 +225,15 @@ def test_data_dir_float(tmpdir):
         "nodata": 0
     }
 
-    with rasterio.drivers():
-        with rasterio.open(str(tmpdir.join('two.tif')), 'w', **kwargs) as dst:
-            data = numpy.zeros((10, 10), dtype=rasterio.float64)
-            data[0:6, 0:6] = 255
-            dst.write_band(1, data)
+    with rasterio.open(str(tmpdir.join('two.tif')), 'w', **kwargs) as dst:
+        data = numpy.zeros((10, 10), dtype=rasterio.float64)
+        data[0:6, 0:6] = 255
+        dst.write(data, indexes=1)
 
-        with rasterio.open(str(tmpdir.join('one.tif')), 'w', **kwargs) as dst:
-            data = numpy.zeros((10, 10), dtype=rasterio.float64)
-            data[4:8, 4:8] = 254
-            dst.write_band(1, data)
+    with rasterio.open(str(tmpdir.join('one.tif')), 'w', **kwargs) as dst:
+        data = numpy.zeros((10, 10), dtype=rasterio.float64)
+        data[4:8, 4:8] = 254
+        dst.write(data, indexes=1)
     return tmpdir
 
 
@@ -253,7 +247,7 @@ def test_merge_float(test_data_dir_float):
     assert os.path.exists(outputname)
     with rasterio.open(outputname) as out:
         assert out.count == 1
-        data = out.read_band(1, masked=False)
+        data = out.read(1, masked=False)
         expected = numpy.ones((10, 10), dtype=rasterio.float64) * -1.5
         expected[0:6, 0:6] = 255
         expected[4:8, 4:8] = 254
@@ -268,29 +262,30 @@ def tiffs(tmpdir):
 
     data = numpy.ones((1, 1, 1), 'uint8')
 
-    kwargs = {'count': '1',
-              'driver': 'GTiff',
-              'dtype': 'uint8',
-              'height': 1,
-              'width': 1}
+    kwargs = {
+        'count': '1',
+        'driver': 'GTiff',
+        'dtype': 'uint8',
+        'height': 1,
+        'width': 1}
 
-    kwargs['transform'] = Affine( 1, 0, 1,
-                                  0,-1, 1)
+    kwargs['transform'] = Affine(1, 0, 1,
+                                 0, -1, 1)
     with rasterio.open(str(tmpdir.join('a-sw.tif')), 'w', **kwargs) as r:
         r.write(data * 40)
 
-    kwargs['transform'] = Affine( 1, 0, 2,
-                                  0,-1, 2)
+    kwargs['transform'] = Affine(1, 0, 2,
+                                 0, -1, 2)
     with rasterio.open(str(tmpdir.join('b-ct.tif')), 'w', **kwargs) as r:
         r.write(data * 60)
 
-    kwargs['transform'] = Affine( 2, 0, 3,
-                                  0,-2, 4)
+    kwargs['transform'] = Affine(2, 0, 3,
+                                 0, -2, 4)
     with rasterio.open(str(tmpdir.join('c-ne.tif')), 'w', **kwargs) as r:
         r.write(data * 90)
 
-    kwargs['transform'] = Affine( 2, 0, 2,
-                                  0,-2, 4)
+    kwargs['transform'] = Affine(2, 0, 2,
+                                 0, -2, 4)
     with rasterio.open(str(tmpdir.join('d-ne.tif')), 'w', **kwargs) as r:
         r.write(data * 120)
 
@@ -314,8 +309,8 @@ def test_merge_tiny(tiffs):
 
     with rasterio.open(outputname) as src:
         data = src.read()
-        assert (data[0][0:2,1] == 120).all()
-        assert (data[0][0:2,2:4] == 90).all()
+        assert (data[0][0:2, 1] == 120).all()
+        assert (data[0][0:2, 2:4] == 90).all()
         assert data[0][2][1] == 60
         assert data[0][3][0] == 40
 
@@ -337,8 +332,8 @@ def test_merge_tiny_output_opt(tiffs):
 
     with rasterio.open(outputname) as src:
         data = src.read()
-        assert (data[0][0:2,1] == 120).all()
-        assert (data[0][0:2,2:4] == 90).all()
+        assert (data[0][0:2, 1] == 120).all()
+        assert (data[0][0:2, 2:4] == 90).all()
         assert data[0][2][1] == 60
         assert data[0][3][0] == 40
 
@@ -399,3 +394,11 @@ def test_merge_rgb(tmpdir):
 
     with rasterio.open(outputname) as src:
         assert [src.checksum(i) for i in src.indexes] == [25420, 29131, 37860]
+
+
+def test_merge_tiny_intres(tiffs):
+    from rasterio.merge import merge
+    inputs = [str(x) for x in tiffs.listdir()]
+    inputs.sort()
+    sources = [rasterio.open(x) for x in inputs]
+    merge(sources, res=2)
