@@ -11,24 +11,23 @@ import rasterio
 
 def test_update_tags(data):
     tiffname = str(data.join('RGB.byte.tif'))
-    with rasterio.drivers():
-        with rasterio.open(tiffname, 'r+') as f:
-            f.update_tags(a='1', b='2')
-            f.update_tags(1, c=3)
-            with pytest.raises(IndexError):
-                f.update_tags(4, d=4)
-            assert f.tags() == {'AREA_OR_POINT': 'Area', 'a': '1', 'b': '2'}
-            assert ('c', '3') in f.tags(1).items()
-        info = subprocess.check_output(["gdalinfo", tiffname]).decode('utf-8')
-        assert re.search("Metadata:\W+a=1\W+AREA_OR_POINT=Area\W+b=2", info)
+    with rasterio.open(tiffname, 'r+') as f:
+        f.update_tags(a='1', b='2')
+        f.update_tags(1, c=3)
+        with pytest.raises(IndexError):
+            f.update_tags(4, d=4)
+        assert f.tags() == {'AREA_OR_POINT': 'Area', 'a': '1', 'b': '2'}
+        assert ('c', '3') in f.tags(1).items()
+    info = subprocess.check_output(["gdalinfo", tiffname]).decode('utf-8')
+    assert re.search("Metadata:\W+a=1\W+AREA_OR_POINT=Area\W+b=2", info)
 
 
 def test_update_band(data):
     tiffname = str(data.join('RGB.byte.tif'))
     with rasterio.open(tiffname, 'r+') as f:
-        f.write_band(1, numpy.zeros(f.shape, dtype=f.dtypes[0]))
+        f.write(numpy.zeros(f.shape, dtype=f.dtypes[0]), indexes=1)
     with rasterio.open(tiffname) as f:
-        assert not f.read_band(1).any()
+        assert not f.read(1).any()
 
 
 def test_update_spatial(data):
@@ -58,7 +57,7 @@ def test_update_nodatavals(data):
     with rasterio.open(tiffname, 'r+') as f:
         f.nodata = 255
     with rasterio.open(tiffname) as f:
-        assert f.nodatavals == [255, 255, 255]
+        assert f.nodatavals == (255, 255, 255)
 
 
 def test_update_nodatavals_error(data):
