@@ -6,8 +6,10 @@ from affine import Affine
 import numpy
 
 import rasterio
+from rasterio.enums import Resampling
+from rasterio.env import Env
 from rasterio.warp import (
-    reproject, Resampling, transform_geom, transform, transform_bounds,
+    reproject, transform_geom, transform, transform_bounds,
     calculate_default_transform)
 
 
@@ -28,7 +30,7 @@ class ReprojectParams(object):
         self.src_crs = src_crs
         self.dst_crs = dst_crs
 
-        with rasterio.drivers():
+        with Env():
             dt, dw, dh = calculate_default_transform(
                 src_crs, dst_crs, width, height, left, bottom, right, top)
             self.dst_transform = dt
@@ -64,7 +66,7 @@ def test_transform():
 
 
 def test_transform_bounds():
-    with rasterio.drivers():
+    with Env():
         with rasterio.open('tests/data/RGB.byte.tif') as src:
             l, b, r, t = src.bounds
             assert numpy.allclose(
@@ -110,7 +112,7 @@ def test_transform_bounds_densify():
 
 def test_transform_bounds_no_change():
     """ Make sure that going from and to the same crs causes no change """
-    with rasterio.drivers():
+    with Env():
         with rasterio.open('tests/data/RGB.byte.tif') as src:
             l, b, r, t = src.bounds
             assert numpy.allclose(
@@ -134,7 +136,7 @@ def test_calculate_default_transform():
         0.0028535715391804096, 0.0, -78.95864996545055,
         0.0, -0.0028535715391804096, 25.550873767433984)
 
-    with rasterio.drivers():
+    with Env():
         with rasterio.open('tests/data/RGB.byte.tif') as src:
             wgs84_crs = {'init': 'EPSG:4326'}
             dst_transform, width, height = calculate_default_transform(
@@ -146,7 +148,7 @@ def test_calculate_default_transform():
 
 
 def test_calculate_default_transform_single_resolution():
-    with rasterio.drivers():
+    with Env():
         with rasterio.open('tests/data/RGB.byte.tif') as src:
             target_resolution = 0.1
             target_transform = Affine(
@@ -164,7 +166,7 @@ def test_calculate_default_transform_single_resolution():
 
 
 def test_calculate_default_transform_multiple_resolutions():
-    with rasterio.drivers():
+    with Env():
         with rasterio.open('tests/data/RGB.byte.tif') as src:
             target_resolution = (0.2, 0.1)
             target_transform = Affine(
@@ -183,9 +185,9 @@ def test_calculate_default_transform_multiple_resolutions():
 
 
 def test_reproject_ndarray():
-    with rasterio.drivers():
+    with Env():
         with rasterio.open('tests/data/RGB.byte.tif') as src:
-            source = src.read_band(1)
+            source = src.read(1)
 
         dst_crs = dict(
             proj='merc',
@@ -213,9 +215,9 @@ def test_reproject_ndarray():
 
 
 def test_reproject_epsg():
-    with rasterio.drivers():
+    with Env():
         with rasterio.open('tests/data/RGB.byte.tif') as src:
-            source = src.read_band(1)
+            source = src.read(1)
 
         dst_crs = {'init': 'EPSG:3857'}
         out = numpy.empty(src.shape, dtype=numpy.uint8)
@@ -232,9 +234,9 @@ def test_reproject_epsg():
 
 def test_reproject_out_of_bounds():
     # using EPSG code not appropriate for the transform should return blank image
-    with rasterio.drivers():
+    with Env():
         with rasterio.open('tests/data/RGB.byte.tif') as src:
-            source = src.read_band(1)
+            source = src.read(1)
 
         dst_crs = {'init': 'EPSG:32619'}
         out = numpy.empty(src.shape, dtype=numpy.uint8)
@@ -253,7 +255,7 @@ def test_reproject_nodata():
     params = default_reproject_params()
     nodata = 215
 
-    with rasterio.drivers():
+    with Env():
         source = numpy.ones((params.width, params.height), dtype=numpy.uint8)
         out = numpy.zeros((params.dst_width, params.dst_height),
                           dtype=source.dtype)
@@ -277,9 +279,8 @@ def test_reproject_nodata():
 
 def test_reproject_nodata_nan():
     params = default_reproject_params()
-    nodata = 215
 
-    with rasterio.drivers():
+    with Env():
         source = numpy.ones((params.width, params.height), dtype=numpy.float32)
         out = numpy.zeros((params.dst_width, params.dst_height),
                           dtype=source.dtype)
@@ -298,8 +299,7 @@ def test_reproject_nodata_nan():
 
         assert (out == 1).sum() == 6215
         assert numpy.isnan(out).sum() == (params.dst_width *
-                                         params.dst_height - 6215)
-
+                                          params.dst_height - 6215)
 
 
 def test_reproject_dst_nodata_default():
@@ -310,7 +310,7 @@ def test_reproject_dst_nodata_default():
 
     params = default_reproject_params()
 
-    with rasterio.drivers():
+    with Env():
         source = numpy.ones((params.width, params.height), dtype=numpy.uint8)
         out = numpy.zeros((params.dst_width, params.dst_height),
                           dtype=source.dtype)
@@ -334,7 +334,7 @@ def test_reproject_invalid_dst_nodata():
     """ dst_nodata must be in value range of data type """
     params = default_reproject_params()
 
-    with rasterio.drivers():
+    with Env():
         source = numpy.ones((params.width, params.height), dtype=numpy.uint8)
         out = source.copy()
 
@@ -355,7 +355,7 @@ def test_reproject_missing_src_nodata():
     """ src_nodata is required if dst_nodata is not None """
     params = default_reproject_params()
 
-    with rasterio.drivers():
+    with Env():
         source = numpy.ones((params.width, params.height), dtype=numpy.uint8)
         out = source.copy()
 
@@ -375,7 +375,7 @@ def test_reproject_invalid_src_nodata():
     """ src_nodata must be in range for data type """
     params = default_reproject_params()
 
-    with rasterio.drivers():
+    with Env():
         source = numpy.ones((params.width, params.height), dtype=numpy.uint8)
         out = source.copy()
 
@@ -394,7 +394,7 @@ def test_reproject_invalid_src_nodata():
 
 def test_reproject_multi():
     """Ndarry to ndarray"""
-    with rasterio.drivers():
+    with Env():
         with rasterio.open('tests/data/RGB.byte.tif') as src:
             source = src.read()
         dst_crs = dict(
@@ -536,9 +536,7 @@ def test_transform_geom():
                 (662054.7979028501, 6772962.86384242),
                 (841909.6014891531, 6731793.200435557),
                 (840726.455490463, 6727039.8672589315),
-                (798842.3090855901, 6569056.500655151)),
-            )
-    }
+                (798842.3090855901, 6569056.500655151)),)}
 
     result = transform_geom('EPSG:3373', 'EPSG:4326', geom)
     assert result['type'] == 'Polygon'
@@ -550,27 +548,27 @@ def test_transform_geom():
     assert len(result['coordinates']) == 2
 
     result = transform_geom(
-        'EPSG:3373', 
-        'EPSG:4326', 
-        geom, 
+        'EPSG:3373',
+        'EPSG:4326',
+        geom,
         antimeridian_cutting=True,
         antimeridian_offset=0)
     assert result['type'] == 'MultiPolygon'
     assert len(result['coordinates']) == 2
 
-    result = transform_geom('EPSG:3373', 'EPSG:4326',  geom,  precision=1)
+    result = transform_geom('EPSG:3373', 'EPSG:4326', geom, precision=1)
     assert int(result['coordinates'][0][0][0] * 10) == -1778
 
 
-def test_reproject_invalid_resampling():
-    # An invalid resampling number fails.
-    with rasterio.drivers():
+def test_reproject_unsupported_resampling():
+    """Values not in enums.Resampling are not supported."""
+    with Env():
         with rasterio.open('tests/data/RGB.byte.tif') as src:
-            source = src.read_band(1)
+            source = src.read(1)
 
         dst_crs = {'init': 'EPSG:32619'}
         out = numpy.empty(src.shape, dtype=numpy.uint8)
-        with pytest.raises(ValueError) as exc_info:
+        with pytest.raises(ValueError):
             reproject(
                 source,
                 out,
@@ -579,4 +577,22 @@ def test_reproject_invalid_resampling():
                 dst_transform=DST_TRANSFORM,
                 dst_crs=dst_crs,
                 resampling=99)
-            assert "99 is not a valid Resampling" in exc_info.value.message
+
+
+def test_reproject_unsupported_resampling_guass():
+    """Resampling.gauss is unsupported."""
+    with Env():
+        with rasterio.open('tests/data/RGB.byte.tif') as src:
+            source = src.read(1)
+
+        dst_crs = {'init': 'EPSG:32619'}
+        out = numpy.empty(src.shape, dtype=numpy.uint8)
+        with pytest.raises(ValueError):
+            reproject(
+                source,
+                out,
+                src_transform=src.transform,
+                src_crs=src.crs,
+                dst_transform=DST_TRANSFORM,
+                dst_crs=dst_crs,
+                resampling=Resampling.gauss)
